@@ -25,7 +25,6 @@ DEFAULT_VALUES = {}
 
 SECTION_PREFERENCES = 'preferences'
 SECTION_APP_PICKER = 'application picker'
-SECTION_HEADERBARS = 'headerbars'
 
 PREFERENCES_SHOW_MISSING = 'show missing files'
 DEFAULT_VALUES[PREFERENCES_SHOW_MISSING] = (SECTION_PREFERENCES, False)
@@ -42,12 +41,12 @@ class Preferences(object):
         self.options = {}
         for option in DEFAULT_VALUES.keys():
             section, default = DEFAULT_VALUES[option]
-            if isinstance(default, int):
-                self.options[option] = settings.settings.get_int(
-                    section, option, default)
-            elif isinstance(default, bool):
+            if isinstance(default, bool):
                 self.options[option] = settings.settings.get_boolean(
                     section, option, default)
+            elif isinstance(default, int):
+                self.options[option] = settings.settings.get_int(
+                    section, option, default)
             else:
                 self.options[option] = settings.settings.get(
                     section, option, default)
